@@ -1,5 +1,5 @@
 from bottlenest.core.NestLogger import *
-from bottlenest.core.NestContainer import *
 from bottlenest.core.NestFactory import *
 from bottlenest.core.NestApplicationContext import *
+from bottlenest.core.NestModuleContext import *
 from bottlenest.common import *
