@@ -1,10 +1,11 @@
 from bottlenest.common import Module
 from bottlenest.transports.cli import CommandFactory
+from bottlenest.corecommands.NewCoreCommand import NewCoreCommand
 from bottlenest.corecommands.BuildCoreCommand import BuildCoreCommand
 
 
 @Module(
-    providers=[BuildCoreCommand],
+    providers=[NewCoreCommand, BuildCoreCommand],
 )
 class CoreCliModule:
     pass
